==> ejc-sealm-api-3.0.0-20220129.010215-38-sources.jar: com.ejianc.business.sealm/vo/YysqVO.java <==
package com.ejianc.business.sealm.vo;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * 用印申请
 * 
 * @author generator
 * 
 */
public class YysqVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String billCode; // 单据编码
    private Long sqdwId; // 申请单位id
    private String sqdwName; // 申请单位名称
    private Long sqxmId; // 申请项目id
    private String sqxmName; // 申请项目名称
    private Long sqrId; // 申请人id
    private String sqrName; // 申请人名称
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private java.util.Date yyDate; // 用印日期
    private Long yzsqId; // 印章申请id
    private Long yzlbId; // 印章类别id
    private String yzlbName; // 印章类别名称
    private Long yzjbId; // 印章级别id
    private String yzjbName; // 印章级别名称
    private Long yylxId; // 用印类型id
    private String yylxName; // 用印类型名称
    private Long zkbmId; // 业务主控部门id
    private String zkbmName; // 业务主控部门名称
    private Integer fs; // 份数（默认1）
    private String yzm; // 验证码
    private String yyReason; // 用印事由
    private String yysx; // 用印事项
    private String yycs; // 用印次数
    private String djlj; // 单据链接
    private Integer messageFrom; // 单据来源（默认1）1自建0推送
    private String remark; // 备注
    private Long orgId; // 组织id
    private String orgName; // 组织名称
    private Integer sfYzsq; // 是否从印章申请同步，默认是0(1:是，0：否)
    private java.util.Date beginDate; // 开始日期
    private java.util.Date endDate; // 结束日期
    private Integer billState; // 单据状态（审批必须字段）
    private String createUserName; // 编制人
    private String updateUserName; // 修改人
    private Long bidId; // 投标ID，关联字段
    private java.lang.String bidCode; // 投标编码
    

    /**
     * 单据编码
     */
    public String getBillCode() {
        return billCode;
    }

    /**
     * 单据编码
     */
    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    /**
     * 申请单位id
     */
    @ReferSerialTransfer(referCode = "idm-org")
    public Long getSqdwId() {
        return sqdwId;
    }

    /**
     * 申请单位id
     */
    @ReferDeserialTransfer
    public void setSqdwId(Long sqdwId) {
        this.sqdwId = sqdwId;
    }
    /**
     * 申请单位名称
     */
    public String getSqdwName() {
        return sqdwName;
    }

    /**
     * 申请单位名称
     */
    public void setSqdwName(String sqdwName) {
        this.sqdwName = sqdwName;
    }
    /**
     * 申请项目id
     */
    @ReferSerialTransfer(referCode = "idm-org")
    public Long getSqxmId() {
        return sqxmId;
    }

    /**
     * 申请项目id
     */
    @ReferDeserialTransfer
    public void setSqxmId(Long sqxmId) {
        this.sqxmId = sqxmId;
    }
    /**
     * 申请项目名称
     */
    public String getSqxmName() {
        return sqxmName;
    }

    /**
     * 申请项目名称
     */
    public void setSqxmName(String sqxmName) {
        this.sqxmName = sqxmName;
    }
    /**
     * 申请人id
     */
    @ReferSerialTransfer(referCode = "idm-user")
    public Long getSqrId() {
        return sqrId;
    }

    /**
     * 申请人id
     */
    @ReferDeserialTransfer
    public void setSqrId(Long sqrId) {
        this.sqrId = sqrId;
    }
    /**
     * 申请人名称
     */
    public String getSqrName() {
        return sqrName;
    }

    /**
     * 申请人名称
     */
    public void setSqrName(String sqrName) {
        this.sqrName = sqrName;
    }
    /**
     * 用印日期
     */
    public java.util.Date getYyDate() {
        return yyDate;
    }

    /**
     * 用印日期
     */
    public void setYyDate(java.util.Date yyDate) {
        this.yyDate = yyDate;
    }
    /**
     * 印章申请id
     */
    public Long getYzsqId() {
        return yzsqId;
    }

    /**
     * 印章申请id
     */
    public void setYzsqId(Long yzsqId) {
        this.yzsqId = yzsqId;
    }
    /**
     * 印章类别id
     */
    @ReferSerialTransfer(referCode = "support-defdoc")
    public Long getYzlbId() {
        return yzlbId;
    }

    /**
     * 印章类别id
     */
    @ReferDeserialTransfer
    public void setYzlbId(Long yzlbId) {
        this.yzlbId = yzlbId;
    }
    /**
     * 印章类别名称
     */
    public String getYzlbName() {
        return yzlbName;
    }

    /**
     * 印章类别名称
     */
    public void setYzlbName(String yzlbName) {
        this.yzlbName = yzlbName;
    }
    /**
     * 印章级别id
     */
    @ReferSerialTransfer(referCode = "support-defdoc")
    public Long getYzjbId() {
        return yzjbId;
    }

    /**
     * 印章级别id
     */
    @ReferDeserialTransfer
    public void setYzjbId(Long yzjbId) {
        this.yzjbId = yzjbId;
    }
    /**
     * 印章级别名称
     */
    public String getYzjbName() {
        return yzjbName;
    }

    /**
     * 印章级别名称
     */
    public void setYzjbName(String yzjbName) {
        this.yzjbName = yzjbName;
    }
    /**
     * 用印类型id
     */
    @ReferSerialTransfer(referCode = "support-defdoc")
    public Long getYylxId() {
        return yylxId;
    }

    /**
     * 用印类型id
     */
    @ReferDeserialTransfer
    public void setYylxId(Long yylxId) {
        this.yylxId = yylxId;
    }
    /**
     * 用印类型名称
     */
    public String getYylxName() {
        return yylxName;
    }

    /**
     * 用印类型名称
     */
    public void setYylxName(String yylxName) {
        this.yylxName = yylxName;
    }
    /**
     * 业务主控部门id
     */
    @ReferSerialTransfer(referCode = "idm-org")
    public Long getZkbmId() {
        return zkbmId;
    }

    /**
     * 业务主控部门id
     */
    @ReferDeserialTransfer
    public void setZkbmId(Long zkbmId) {
        this.zkbmId = zkbmId;
    }
    /**
     * 业务主控部门名称
     */
    public String getZkbmName() {
        return zkbmName;
    }

    /**
     * 业务主控部门名称
     */
    public void setZkbmName(String zkbmName) {
        this.zkbmName = zkbmName;
    }
    /**
     * 份数（默认1）
     */
    public Integer getFs() {
        return fs;
    }

    /**
     * 份数（默认1）
     */
    public void setFs(Integer fs) {
        this.fs = fs;
    }
    /**
     * 验证码
     */
    public String getYzm() {
        return yzm;
    }

    /**
     * 验证码
     */
    public void setYzm(String yzm) {
        this.yzm = yzm;
    }
    /**
     * 用印事由
     */
    public String getYyReason() {
        return yyReason;
    }

    /**
     * 用印事由
     */
    public void setYyReason(String yyReason) {
        this.yyReason = yyReason;
    }
    /**
     * 用印事项
     */
    public String getYysx() {
        return yysx;
    }

    /**
     * 用印事项
     */
    public void setYysx(String yysx) {
        this.yysx = yysx;
    }
    /**
     * 用印次数
     */
    public String getYycs() {
        return yycs;
    }

    /**
     * 用印次数
     */
    public void setYycs(String yycs) {
        this.yycs = yycs;
    }
    /**
     * 单据链接
     */
    public String getDjlj() {
        return djlj;
    }

    /**
     * 单据链接
     */
    public void setDjlj(String djlj) {
        this.djlj = djlj;
    }
    /**
     * 单据来源（默认1）1自建0推送
     */
    public Integer getMessageFrom() {
        return messageFrom;
    }

    /**
     * 单据来源（默认1）1自建0推送
     */
    public void setMessageFrom(Integer messageFrom) {
        this.messageFrom = messageFrom;
    }
    /**
     * 备注
     */
    public String getRemark() {
        return remark;
    }

    /**
     * 备注
     */
    public void setRemark(String remark) {
        this.remark = remark;
    }
    /**
     * 组织id
     */
    @ReferSerialTransfer(referCode = "idm-org")
    public Long getOrgId() {
        return orgId;
    }

    /**
     * 组织id
     */
    @ReferDeserialTransfer
    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 组织名称
     */
    public String getOrgName() {
        return orgName;
    }

    /**
     * 组织名称
     */
    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    /**
     * 是否从印章申请同步，默认是0(1:是，0：否)
     */
    public Integer getSfYzsq() {
        return sfYzsq;
    }

    /**
     * 是否从印章申请同步，默认是0(1:是，0：否)
     */
    public void setSfYzsq(Integer sfYzsq) {
        this.sfYzsq = sfYzsq;
    }
    /**
     * 开始日期
     */
    public java.util.Date getBeginDate() {
        return beginDate;
    }

    /**
     * 开始日期
     */
    public void setBeginDate(java.util.Date beginDate) {
        this.beginDate = beginDate;
    }
    /**
     * 结束日期
     */
    public java.util.Date getEndDate() {
        return endDate;
    }

    /**
     * 结束日期
     */
    public void setEndDate(java.util.Date endDate) {
        this.endDate = endDate;
    }
    /**
     * 单据状态（审批必须字段）
     */
    public Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态（审批必须字段）
     */
    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    /**
     * 编制人
     */
    public String getCreateUserName() {
        return createUserName;
    }

    /**
     * 编制人
     */
    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    /**
     * 修改人
     */
    public String getUpdateUserName() {
        return updateUserName;
    }

    /**
     * 修改人
     */
    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }
    /**
     * 投标ID，关联字段
     */
    public Long getBidId() {
        return bidId;
    }

    /**
     * 投标ID，关联字段
     */
    public void setBidId(Long bidId) {
        this.bidId = bidId;
    }

    /**
     * 投标编码
     */
    public java.lang.String getBidCode() {
        return bidCode;
    }

    /**
     * 投标编码
     */
    public void setBidCode(java.lang.String bidCode) {
        this.bidCode = bidCode;
    }
    
}

==> ejc-sealm-api-3.0.0-20230210.024612-133-sources.jar: com.ejianc.business.sealm/vo/YysqVO.java <==
package com.ejianc.business.sealm.vo;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * 用印申请
 * 
 * @author generator
 * 
 */
public class YysqVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String billCode; // 单据编码
    private Long sqdwId; // 申请单位id
    private String sqdwName; // 申请单位名称
    private Long sqxmId; // 申请项目id
    private String sqxmName; // 申请项目名称
    private Long sqrId; // 申请人id
    private String sqrName; // 申请人名称
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private java.util.Date yyDate; // 用印日期
    private Long yzsqId; // 印章申请id
    private Long yzlbId; // 印章类别id
    private String yzlbName; // 印章类别名称
    private Long yzjbId; // 印章级别id
    private String yzjbName; // 印章级别名称
    private Long yylxId; // 用印类型id
    private String yylxName; // 用印类型名称
    private Long zkbmId; // 业务主控部门id
    private String zkbmName; // 业务主控部门名称
    private Integer fs; // 份数（默认1）
    private String yzm; // 验证码
    private String yyReason; // 用印事由
    private Long yysxId; // 用印事项id
    private String yysxName; // 用印事项名称
    private String yysxCode; // 用印事项code
    private String yycs; // 用印次数
    private String djlj; // 单据链接
    private Integer messageFrom; // 单据来源（默认1）1自建0推送
    private String remark; // 备注
    private Long orgId; // 组织id
    private String orgName; // 组织名称
    private Integer sfYzsq; // 是否从印章申请同步，默认是0(1:是，0：否)
    private java.util.Date beginDate; // 开始日期
    private java.util.Date endDate; // 结束日期
    private Integer billState; // 单据状态（审批必须字段）
    private String createUserName; // 编制人
    private String updateUserName; // 修改人
    private Long bidId; // 投标ID，关联字段
    private java.lang.String bidCode; // 投标编码
    private Long yzcyrId; // 印章持有人id
    private String yzcyrName; // 印章持有人名称
    private Integer xgcs; // 修改次数
    private Long yybdId; // 记录用印事项选择的表单id,用于单据编号参照选择时区分
    private Long yzbhId; // 印章编号id
    private String yzbhCode; // 印章编号code，对应印章登记里的印章编号
    private String yzbhName; // 印章编号名称
    private Long attachmentFileId; // 签章文件id
    private String attachmentFileName; // 签章文件名称
    private String signatureStatus; // 签章状态（1表示已签章）



    /**
     * 单据编码
     */
    public String getBillCode() {
        return billCode;
    }

    /**
     * 单据编码
     */
    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    /**
     * 申请单位id
     */
    @ReferSerialTransfer(referCode = "idm-org")
    public Long getSqdwId() {
        return sqdwId;
    }

    /**
     * 申请单位id
     */
    @ReferDeserialTransfer
    public void setSqdwId(Long sqdwId) {
        this.sqdwId = sqdwId;
    }
    /**
     * 申请单位名称
     */
    public String getSqdwName() {
        return sqdwName;
    }

    /**
     * 申请单位名称
     */
    public void setSqdwName(String sqdwName) {
        this.sqdwName = sqdwName;
    }
    /**
     * 申请项目id
     */
    @ReferSerialTransfer(referCode = "idm-org")
    public Long getSqxmId() {
        return sqxmId;
    }

    /**
     * 申请项目id
     */
    @ReferDeserialTransfer
    public void setSqxmId(Long sqxmId) {
        this.sqxmId = sqxmId;
    }
    /**
     * 申请项目名称
     */
    public String getSqxmName() {
        return sqxmName;
    }

    /**
     * 申请项目名称
     */
    public void setSqxmName(String sqxmName) {
        this.sqxmName = sqxmName;
    }
    /**
     * 申请人id
     */
    @ReferSerialTransfer(referCode = "idm-user")
    public Long getSqrId() {
        return sqrId;
    }

    /**
     * 申请人id
     */
    @ReferDeserialTransfer
    public void setSqrId(Long sqrId) {
        this.sqrId = sqrId;
    }
    /**
     * 申请人名称
     */
    public String getSqrName() {
        return sqrName;
    }

    /**
     * 申请人名称
     */
    public void setSqrName(String sqrName) {
        this.sqrName = sqrName;
    }
    /**
     * 用印日期
     */
    public java.util.Date getYyDate() {
        return yyDate;
    }

    /**
     * 用印日期
     */
    public void setYyDate(java.util.Date yyDate) {
        this.yyDate = yyDate;
    }
    /**
     * 印章申请id
     */
    public Long getYzsqId() {
        return yzsqId;
    }

    /**
     * 印章申请id
     */
    public void setYzsqId(Long yzsqId) {
        this.yzsqId = yzsqId;
    }
    /**
     * 印章类别id
     */
    @ReferSerialTransfer(referCode = "support-defdoc")
    public Long getYzlbId() {
        return yzlbId;
    }

    /**
     * 印章类别id
     */
    @ReferDeserialTransfer
    public void setYzlbId(Long yzlbId) {
        this.yzlbId = yzlbId;
    }
    /**
     * 印章类别名称
     */
    public String getYzlbName() {
        return yzlbName;
    }

    /**
     * 印章类别名称
     */
    public void setYzlbName(String yzlbName) {
        this.yzlbName = yzlbName;
    }
    /**
     * 印章级别id
     */
    @ReferSerialTransfer(referCode = "support-defdoc")
    public Long getYzjbId() {
        return yzjbId;
    }

    /**
     * 印章级别id
     */
    @ReferDeserialTransfer
    public void setYzjbId(Long yzjbId) {
        this.yzjbId = yzjbId;
    }
    /**
     * 印章级别名称
     */
    public String getYzjbName() {
        return yzjbName;
    }

    /**
     * 印章级别名称
     */
    public void setYzjbName(String yzjbName) {
        this.yzjbName = yzjbName;
    }
    /**
     * 用印类型id
     */
    @ReferSerialTransfer(referCode = "support-defdoc")
    public Long getYylxId() {
        return yylxId;
    }

    /**
     * 用印类型id
     */
    @ReferDeserialTransfer
    public void setYylxId(Long yylxId) {
        this.yylxId = yylxId;
    }
    /**
     * 用印类型名称
     */
    public String getYylxName() {
        return yylxName;
    }

    /**
     * 用印类型名称
     */
    public void setYylxName(String yylxName) {
        this.yylxName = yylxName;
    }
    /**
     * 业务主控部门id
     */
    @ReferSerialTransfer(referCode = "idm-dept")
    public Long getZkbmId() {
        return zkbmId;
    }

    /**
     * 业务主控部门id
     */
    @ReferDeserialTransfer
    public void setZkbmId(Long zkbmId) {
        this.zkbmId = zkbmId;
    }
    /**
     * 业务主控部门名称
     */
    public String getZkbmName() {
        return zkbmName;
    }

    /**
     * 业务主控部门名称
     */
    public void setZkbmName(String zkbmName) {
        this.zkbmName = zkbmName;
    }
    /**
     * 份数（默认1）
     */
    public Integer getFs() {
        return fs;
    }

    /**
     * 份数（默认1）
     */
    public void setFs(Integer fs) {
        this.fs = fs;
    }
    /**
     * 验证码
     */
    public String getYzm() {
        return yzm;
    }

    /**
     * 验证码
     */
    public void setYzm(String yzm) {
        this.yzm = yzm;
    }
    /**
     * 用印事由
     */
    public String getYyReason() {
        return yyReason;
    }

    /**
     * 用印事由
     */
    public void setYyReason(String yyReason) {
        this.yyReason = yyReason;
    }

    /**
     * 用印事项id
     */
    @ReferSerialTransfer(referCode = "sealm-yyzd")
    public Long getYysxId() {
        return yysxId;
    }
    /**
     * 用印事项id
     */
    @ReferDeserialTransfer
    public void setYysxId(Long yysxId) {
        this.yysxId = yysxId;
    }
    /**
     * 用印事项名称
     */
    public String getYysxName() {
        return yysxName;
    }
    /**
     * 用印事项名称
     */
    public void setYysxName(String yysxName) {
        this.yysxName = yysxName;
    }
    /**
     * 用印事项code
     */
    public String getYysxCode() {
        return yysxCode;
    }
    /**
     * 用印事项code
     */
    public void setYysxCode(String yysxCode) {
        this.yysxCode = yysxCode;
    }



    /**
     * 用印次数
     */
    public String getYycs() {
        return yycs;
    }

    /**
     * 用印次数
     */
    public void setYycs(String yycs) {
        this.yycs = yycs;
    }
    /**
     * 单据链接
     */
    public String getDjlj() {
        return djlj;
    }

    /**
     * 单据链接
     */
    public void setDjlj(String djlj) {
        this.djlj = djlj;
    }
    /**
     * 单据来源（默认1）1自建0推送
     */
    public Integer getMessageFrom() {
        return messageFrom;
    }

    /**
     * 单据来源（默认1）1自建0推送
     */
    public void setMessageFrom(Integer messageFrom) {
        this.messageFrom = messageFrom;
    }
    /**
     * 备注
     */
    public String getRemark() {
        return remark;
    }

    /**
     * 备注
     */
    public void setRemark(String remark) {
        this.remark = remark;
    }
    /**
     * 组织id
     */
    @ReferSerialTransfer(referCode = "idm-org")
    public Long getOrgId() {
        return orgId;
    }

    /**
     * 组织id
     */
    @ReferDeserialTransfer
    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 组织名称
     */
    public String getOrgName() {
        return orgName;
    }

    /**
     * 组织名称
     */
    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    /**
     * 是否从印章申请同步，默认是0(1:是，0：否)
     */
    public Integer getSfYzsq() {
        return sfYzsq;
    }

    /**
     * 是否从印章申请同步，默认是0(1:是，0：否)
     */
    public void setSfYzsq(Integer sfYzsq) {
        this.sfYzsq = sfYzsq;
    }
    /**
     * 开始日期
     */
    public java.util.Date getBeginDate() {
        return beginDate;
    }

    /**
     * 开始日期
     */
    public void setBeginDate(java.util.Date beginDate) {
        this.beginDate = beginDate;
    }
    /**
     * 结束日期
     */
    public java.util.Date getEndDate() {
        return endDate;
    }

    /**
     * 结束日期
     */
    public void setEndDate(java.util.Date endDate) {
        this.endDate = endDate;
    }
    /**
     * 单据状态（审批必须字段）
     */
    public Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态（审批必须字段）
     */
    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    /**
     * 编制人
     */
    public String getCreateUserName() {
        return createUserName;
    }

    /**
     * 编制人
     */
    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    /**
     * 修改人
     */
    public String getUpdateUserName() {
        return updateUserName;
    }

    /**
     * 修改人
     */
    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }
    /**
     * 投标ID，关联字段
     */
//    @ReferSerialTransfer(referCode = "bid-enroll,bid-prequali,bid-review,proincome-contract-review,proincome-claim,proincome-settle,proincome-finalized")
    public Long getBidId() {
        return bidId;
    }

    /**
     * 投标ID，关联字段
     */
//    @ReferDeserialTransfer
    public void setBidId(Long bidId) {
        this.bidId = bidId;
    }

    /**
     * 投标编码
     */
    public java.lang.String getBidCode() {
        return bidCode;
    }

    /**
     * 投标编码
     */
    public void setBidCode(java.lang.String bidCode) {
        this.bidCode = bidCode;
    }

    /**
     * 印章持有人id
     */
    @ReferSerialTransfer(referCode = "idm-user")
    public Long getYzcyrId() {
        return yzcyrId;
    }

    /**
     * 印章持有人id
     */
    @ReferDeserialTransfer
    public void setYzcyrId(Long yzcyrId) {
        this.yzcyrId = yzcyrId;
    }

    /**
     * 印章持有人名称
     */
    public String getYzcyrName() {
        return yzcyrName;
    }

    /**
     * 印章持有人名称
     */
    public void setYzcyrName(String yzcyrName) {
        this.yzcyrName = yzcyrName;
    }

    /**
     * 修改次数
     */
    public Integer getXgcs() {
        return xgcs;
    }

    /**
     * 修改次数
     */
    public void setXgcs(Integer xgcs) {
        this.xgcs = xgcs;
    }

    public Long getYybdId() {
        return yybdId;
    }

    public void setYybdId(Long yybdId) {
        this.yybdId = yybdId;
    }
    @ReferSerialTransfer(referCode = "sealm-zzyz")
    public Long getYzbhId() {
        return yzbhId;
    }
    @ReferDeserialTransfer
    public void setYzbhId(Long yzbhId) {
        this.yzbhId = yzbhId;
    }
    public String getYzbhCode() {
        return yzbhCode;
    }

    public void setYzbhCode(String yzbhCode) {
        this.yzbhCode = yzbhCode;
    }
    public String getYzbhName() {
        return yzbhName;
    }

    public void setYzbhName(String yzbhName) {
        this.yzbhName = yzbhName;
    }

    public Long getAttachmentFileId() {
        return attachmentFileId;
    }

    public void setAttachmentFileId(Long attachmentFileId) {
        this.attachmentFileId = attachmentFileId;
    }
    public String getAttachmentFileName() {
        return attachmentFileName;
    }

    public void setAttachmentFileName(String attachmentFileName) {
        this.attachmentFileName = attachmentFileName;
    }
    public String getSignatureStatus() {
        return signatureStatus;
    }

    public void setSignatureStatus(String signatureStatus) {
        this.signatureStatus = signatureStatus;
    }

}
